BOOST_PP_LIMIT_REPEAT

The BOOST_PP_LIMIT_REPEAT macro defines the maximum number of repetitions supported by each BOOST_PP_REPEAT dimension.

#### Usage

BOOST_PP_LIMIT_REPEAT

#### Remarks

This macro current expands to 256.
NOTE: for the current latest versions of Microsoft's VC++ compiler there is a nested macro limit of 256. This means in actuality that the number of repetitions using VC++ is actually less than 256 depending on the repetition macro being used. For the BOOST_PP_REPEAT macro this limit appears to be 252 while for the BOOST_PP_ENUM... series of macros this limit appears to be around 230, before the VC++ compiler gives a "C1009: compiler limit : macros nested too deeply" error. This is a compiler limitation of VC++ which may vary depending on the specific repetition macro being used, and therefore is not a problem the preprocessor library can solve.

#### Requirements

Header: <boost/preprocessor/config/limits.hpp>

© Copyright Housemarque Oy 2002
© Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)